# cnert

[![PyPI version](https://badge.fury.io/py/cnert.svg)](https://badge.fury.io/py/cnert)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/maartenq/cnert/main.svg)](https://results.pre-commit.ci/latest/github/maartenq/cnert/main)
[![workflow ci](https://github.com/maartenq/cnert/actions/workflows/ci.yml/badge.svg)](https://github.com/maartenq/cnert/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/maartenq/cnert/branch/main/graph/badge.svg?token=XXXXXXXXXX)](https://codecov.io/gh/maartenq/cnert)

Cnert makes TLS private keys, CSRs, private CAs and certificates.


## Credits

This project setup was done with the friendly assistance of [Cookiecutter] and
the [maartenq/cookiecutter-pypackage] project template.

[Cookiecutter]: https://github.com/audreyr/cookiecutter
[maartenq/cookiecutter-pypackage]: https://github.com/maartenq/cookiecutter-pypackage
